#!/usr/bin/env python3
#
#  This file is part of ProfileView.
#
#  ProfileView is free software: you can redistribute it and/or modify
#  it under the terms of the CeCILL 2.1 Licence
#
#  ProfileView is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  You should have received a copy of the Licence CeCILL 2.1 along
#  with ProfileView. If not, see <https://cecill.info/>.
#

import os, sys
import re

script_name = re.sub( r'\.py$', '', os.path.basename(sys.argv[0]) )

def uniq(l):
    return list(set(l))

# stable uniq
def suniq(l):
    outlist=[]
    procs=set() # processed elements
    for e in l:
        if e not in procs:
            procs.add(e)
            outlist.append(e)
    return outlist


def eprint(*args, **kwargs):
    print(*args, file=sys.stderr, **kwargs)


def print_status(msg):
    eprint("[{name}] {m}".format(name=script_name,m=msg))


def print_error(msg):
    eprint("[{name}] error: {m}".format(name=script_name,m=msg))


def print_warning(msg):
    eprint("[{name}] warning: {m}".format(name=script_name,m=msg))


def is_int(s):
    try:
        int(s)
        return True
    except ValueError:
        return False

def peekline(f):
    pos = f.tell()
    line = f.readline()
    f.seek(pos)
    return line

